#
# spec file for package xdg-desktop-portal-cosmic
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-desktop-portal-cosmic
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        COSMIC xdg portal
License:        GPL-3.0-only
URL:            https://github.com/pop-os/xdg-desktop-portal-cosmic
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Patch0:         leap-fix-libexec.patch
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xdg-desktop-portal)
BuildRequires:  pkgconfig(xkbcommon)

%description
This package contains the xdg portal implementation for COSMIC DE.

%prep
%autosetup -N -a1
%if 0%{?suse_version} < 1600
%autopatch -p0
%endif

%build
%make_build

%install
%make_install DESTDIR=%{buildroot} prefix=%{_prefix}

%check
%{cargo_test}

%files
%license LICENSE
%{_libexecdir}/%{name}
%{_datadir}/icons/hicolor/scalable/actions/{screenshot-screen-symbolic,screenshot-selection-symbolic,screenshot-window-symbolic}.svg
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.cosmic.service
%{_datadir}/xdg-desktop-portal/cosmic-portals.conf
%{_datadir}/xdg-desktop-portal/portals/cosmic.portal

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * i18n(pt): add Portuguese translation
  * Create xdg_desktop_portal_cosmic.ftl
  * Added Irish translation
  * i18n(ro): Add Romanian translation
  * screenshot: Only resize image if needed
  * screenshot: Share code between rectangle select, and non-interactive
  * screenshot: De-duplicate png encoding code
  * screenshot: Don't use document portal
  * Removed unused dropdown model
  * Pass `&ScreenshotImage` as argument instead of `image::Handle`
  * Add `ScreenshotImage`, and avoid creating image `Handle` in view
  * Remove now unused `MyImage` type
  * Do not convert `RgbaImage` to tuple and back
  * Take slice instead of `Vec` in `screenshot_inner`
  * widget/rectangle_selection: Use `.round()` when converting to integer
  * widget/rectange_selection: Make members private
  * screenshot: Use `FuturesUnordered` in `interactive_toplevel_images`
  * wayland: Use `FuturesOrdered` in `capture_output_toplevels_shm`
  * screencast: Use `wait_for_formats` directly; without shm capture
  * wayland: Make `wait_for_formats` return `None` if stopped
  * wayland: Make `wait_for_formats` async
  * Update cosmic-files
  * Update dependencies
  * chore: update libcosmic
  * i18n(zh-TW): add Taiwanese translation
  * Updated xdg_desktop_portal_cosmic.ftl for Turkish
  * screencast: Accumulate buffer damage instead of damaging whole buffer
  * Pass buffer damage to screencopy/image-copy
  * fix(libcosmic): theme subscription
  * Update to workspace v2, based on ext-workspace
  * i18n(nl) provide Dutch translation
  * i18n(it): update italian translation
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+1:
  * fix(examples): changes in ashpd API
  * chore: upgrade all dependencies
  * Update for toplevel-info cctk changes
  * chore: update libcosmic with built-in mmap threshold fix
  * chore: update dependencies
  * fix(file_chooser): disable a11y feature of libcosmic to fix crash
  * Use updated screencopy abstraction
  * fix: set M_MMAP_THRESHOLD to prevent glibc memory fragmentation
  * chore(cargo): use thin LTO on release profile
  * Create xdg_desktop_portal_cosmic.ftl
  * Update Hungarian translations
  * fix(screenshot): Localized time names
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+1:
  * Update dependencies
  * perf: optimized cosmic-freedesktop-icons
  * update freedesktop-icons
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * update deps
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * fix: wrap windows in a scrollable after 8 toplevels, and add max sizes
  * fix: save screenshot to clipboard
  * Fix auto-sizing of access portal dialog
  * acccess: Fixes for handling of choices
  * access: Use `dialog` widget
  * Update access.rs
  * Derive `Debug` for `Event`
  * Add a `on_cancel` callback method to `Request::run`
  * Add a `Request::run` helper for running cancellable task
  * screencast: Pass buffer transform to pipewire metadata
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * update dependencies
* Tue Oct  8 2024 Richard Rahl <rrahl0@opensuse.org>
- require rust >= 1.80
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Update cosmic-files and enable gvfs feature
  * Update translations and dependencies
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * Fix compile warnings
  * Add scrolling for list of toplevels
  * Hover and selected styles for outputs in screencast dialog
  * Use custom widget instead of global subscription for keybindings
  * screencopy: Respect source_type option
  * Allow multiple select for screencast only when requested
  * Arrange screen capture outputs horiozontally
  * Display name of application requiring screen capture
  * Show preview of outputs in screencast dialog
  * Show toplevel icons in screencast dialog
  * Fix button text color
- enable leap with patch leap-fix-libexec.patch (thanks to vyvir)
* Sat Jul  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Use tar_scm -- gh#openSUSE/obs-service-tar_scm#493
- Update to version 0.1.0+git20240703.b221b3e:
  * FileChooser portal
  * Fix passing fd to pipewire in example.
  * fix: Change remaining `dbus_interface` uses to `zbus`
  * l10n(ru): Add Russian l10n
  * fix: change color-schem on theme mode change
  * update libcosmic
  * fix: add clipboard scheme to handle cases with no uri
  * feat: implement design
  * feat: copy screenshot to clipboard
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
